=== modified file 'olive.glade'
--- olive.glade	2006-09-28 06:35:56 +0000
+++ olive.glade	2006-09-30 11:01:59 +0000
@@ -1305,7 +1305,7 @@
 <widget class="GtkDialog" id="window_add">
   <property name="visible">True</property>
   <property name="title" translatable="yes">Olive - Add file(s)</property>
-  <property name="type">GTK_WINDOW_POPUP</property>
+  <property name="type">GTK_WINDOW_TOPLEVEL</property>
   <property name="window_position">GTK_WIN_POS_NONE</property>
   <property name="modal">False</property>
   <property name="resizable">False</property>
@@ -2423,7 +2423,7 @@
 <widget class="GtkDialog" id="window_mkdir">
   <property name="visible">True</property>
   <property name="title" translatable="yes">Olive - Make directory</property>
-  <property name="type">GTK_WINDOW_POPUP</property>
+  <property name="type">GTK_WINDOW_TOPLEVEL</property>
   <property name="window_position">GTK_WIN_POS_NONE</property>
   <property name="modal">False</property>
   <property name="resizable">True</property>
@@ -2591,7 +2591,7 @@
 <widget class="GtkDialog" id="window_move">
   <property name="width_request">250</property>
   <property name="title" translatable="yes">Olive - Move</property>
-  <property name="type">GTK_WINDOW_POPUP</property>
+  <property name="type">GTK_WINDOW_TOPLEVEL</property>
   <property name="window_position">GTK_WIN_POS_NONE</property>
   <property name="modal">False</property>
   <property name="resizable">True</property>

=== modified file 'olive/move.py'
--- olive/move.py	2006-09-27 20:30:59 +0000
+++ olive/move.py	2006-09-30 11:01:59 +0000
@@ -15,7 +15,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os
-import sys
+from os.path import dirname
 
 try:
     import pygtk
@@ -27,18 +27,17 @@
 import gtk.glade
 
 import bzrlib.errors as errors
+from bzrlib.workingtree import WorkingTree
 
 from olive import gladefile
+from dialog import error_dialog
 
 class OliveMove:
     """ Display the Move dialog and perform the needed actions. """
-    def __init__(self, comm):
+    def __init__(self, wt, wtpath, selected=[]):
         """ Initialize the Move dialog. """
         self.glade = gtk.glade.XML(gladefile, 'window_move', 'olive-gtk')
         
-        # Communication object
-        self.comm = comm
-        
         self.window = self.glade.get_widget('window_move')
         
         # Dictionary for signal_autoconnect
@@ -48,9 +47,21 @@
         # Connect the signals to the handlers
         self.glade.signal_autoconnect(dic)
         
+        self.wt = wt
+        self.wtpath = wtpath
+        self.selected = selected
+        
+        if self.selected is None:
+            self.selected = ""
+        
+        if self.wtpath == "":
+            directory = dirname(self.wt.abspath(self.selected))
+        else:
+            directory = dirname(self.wt.abspath(self.wtpath + os.sep + self.selected))
+        
         # Set FileChooser directory
         self.filechooser = self.glade.get_widget('filechooserbutton_move')
-        self.filechooser.set_filename(self.comm.get_path())
+        self.filechooser.set_filename(directory)
 
     def display(self):
         """ Display the Move dialog. """
@@ -59,14 +70,17 @@
     def move(self, widget):
         destination = self.filechooser.get_filename()
 
-        filename = self.comm.get_selected_right()
+        filename = self.selected
             
         if filename is None:
             error_dialog(_('No file was selected'),
-                                     _('Please select a file from the list to proceed.'))
+                         _('Please select a file from the list to proceed.'))
             return
         
-        source = self.comm.get_path() + '/' + filename
+        if self.wtpath == "":
+            source = self.wt.abspath(filename)
+        else:
+            source = self.wt.abspath(self.wtpath + os.sep + filename)
         
         # Move the file to a directory
         try:
@@ -74,17 +88,16 @@
             wt2, path2 = WorkingTree.open_containing(destination)
             if wt1.base != wt2.base:
                 error_dialog(_('Not the same branch'),
-                                         _('The destination is not in the same branch.'))
+                             _('The destination is not in the same branch.'))
                 return
 
             wt1.move([source], destination)
         except errors.NotBranchError:
             error_dialog(_('File is not in a branch'),
-                                     _('The selected file is not in a branch.'))
+                         _('The selected file is not in a branch.'))
             return
 
         self.close()
-        self.comm.refresh_right()
     
     def close(self, widget=None):
         self.window.destroy()

=== modified file 'olive/rename.py'
--- olive/rename.py	2006-09-27 20:30:59 +0000
+++ olive/rename.py	2006-09-30 11:01:59 +0000
@@ -15,7 +15,6 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os
-import sys
 
 try:
     import pygtk
@@ -27,16 +26,17 @@
 import gtk.glade
 
 import bzrlib.errors as errors
+from bzrlib.workingtree import WorkingTree
+
+from olive import gladefile
+from dialog import error_dialog
 
 class OliveRename:
     """ Display the Rename dialog and perform the needed actions. """
-    def __init__(self, comm):
+    def __init__(self, wt, wtpath, selected=[]):
         """ Initialize the Rename dialog. """
         self.glade = gtk.glade.XML(gladefile, 'window_rename')
         
-        # Communication object
-        self.comm = comm
-        
         self.window = self.glade.get_widget('window_rename')
         
         # Dictionary for signal_autoconnect
@@ -46,6 +46,10 @@
         # Connect the signals to the handlers
         self.glade.signal_autoconnect(dic)
         
+        self.wt = wt
+        self.wtpath = wtpath
+        self.selected = selected
+        
     def display(self):
         """ Display the Rename dialog. """
         self.window.show_all()
@@ -54,21 +58,25 @@
         # Get entry
         entry = self.glade.get_widget('entry_rename')
         
-        old_filename = self.comm.get_selected_right()
+        old_filename = self.selected
         new_filename = entry.get_text()
             
         if old_filename is None:
             error_dialog(_('No file was selected'),
-                                     _('Please select a file from the list to proceed.'))
+                         _('Please select a file from the list to proceed.'))
             return
         
         if new_filename == "":
             error_dialog(_('Filename not given'),
-                                     _('Please specify a new name for the file.'))
+                         _('Please specify a new name for the file.'))
             return
         
-        source = self.comm.get_path() + '/' + old_filename
-        destination = self.comm.get_path() + '/' + new_filename
+        if self.wtpath == "":
+            source = self.wt.abspath(old_filename)
+            destination = self.wt.abspath(new_filename)
+        else:
+            source = self.wt.abspath(self.wtpath + os.sep + old_filename)
+            destination = self.wt.abspath(self.wtpath + os.sep + new_filename)
         
         # Rename the file
         try:
@@ -77,16 +85,15 @@
 
             if wt1.base != wt2.base:
                 error_dialog(_('Not the same branch'),
-                                         _('The destination is not in the same branch.'))
+                             _('The destination is not in the same branch.'))
                 return
             wt1.rename_one(source, destination)
         except errors.NotBranchError:
             error_dialog(_('File is not in a branch'),
-                                     _('The selected file is not in a branch.'))
+                         _('The selected file is not in a branch.'))
             return
 
         self.close()
-        self.comm.refresh_right()
     
     def close(self, widget=None):
         self.window.destroy()

